@@ -1,7 +1,7 @@
 """
 Type annotations for chime-sdk-identity service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/type_defs/)
 
 Usage::
 
@@ -93,99 +93,109 @@ __all__ = (
 AppInstanceAdminSummaryTypeDef = TypedDict(
     "AppInstanceAdminSummaryTypeDef",
     {
-        "Admin": NotRequired["IdentityTypeDef"],
+        "Admin": "IdentityTypeDef",
     },
+    total=False,
 )
 
 AppInstanceAdminTypeDef = TypedDict(
     "AppInstanceAdminTypeDef",
     {
-        "Admin": NotRequired["IdentityTypeDef"],
-        "AppInstanceArn": NotRequired[str],
-        "CreatedTimestamp": NotRequired[datetime],
+        "Admin": "IdentityTypeDef",
+        "AppInstanceArn": str,
+        "CreatedTimestamp": datetime,
     },
+    total=False,
 )
 
 AppInstanceRetentionSettingsTypeDef = TypedDict(
     "AppInstanceRetentionSettingsTypeDef",
     {
-        "ChannelRetentionSettings": NotRequired["ChannelRetentionSettingsTypeDef"],
+        "ChannelRetentionSettings": "ChannelRetentionSettingsTypeDef",
     },
+    total=False,
 )
 
 AppInstanceSummaryTypeDef = TypedDict(
     "AppInstanceSummaryTypeDef",
     {
-        "AppInstanceArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Metadata": NotRequired[str],
+        "AppInstanceArn": str,
+        "Name": str,
+        "Metadata": str,
     },
+    total=False,
 )
 
 AppInstanceTypeDef = TypedDict(
     "AppInstanceTypeDef",
     {
-        "AppInstanceArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "CreatedTimestamp": NotRequired[datetime],
-        "LastUpdatedTimestamp": NotRequired[datetime],
-        "Metadata": NotRequired[str],
+        "AppInstanceArn": str,
+        "Name": str,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "Metadata": str,
     },
+    total=False,
 )
 
 AppInstanceUserEndpointSummaryTypeDef = TypedDict(
     "AppInstanceUserEndpointSummaryTypeDef",
     {
-        "AppInstanceUserArn": NotRequired[str],
-        "EndpointId": NotRequired[str],
-        "Name": NotRequired[str],
-        "Type": NotRequired[AppInstanceUserEndpointTypeType],
-        "AllowMessages": NotRequired[AllowMessagesType],
-        "EndpointState": NotRequired["EndpointStateTypeDef"],
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "Name": str,
+        "Type": AppInstanceUserEndpointTypeType,
+        "AllowMessages": AllowMessagesType,
+        "EndpointState": "EndpointStateTypeDef",
     },
+    total=False,
 )
 
 AppInstanceUserEndpointTypeDef = TypedDict(
     "AppInstanceUserEndpointTypeDef",
     {
-        "AppInstanceUserArn": NotRequired[str],
-        "EndpointId": NotRequired[str],
-        "Name": NotRequired[str],
-        "Type": NotRequired[AppInstanceUserEndpointTypeType],
-        "ResourceArn": NotRequired[str],
-        "EndpointAttributes": NotRequired["EndpointAttributesTypeDef"],
-        "CreatedTimestamp": NotRequired[datetime],
-        "LastUpdatedTimestamp": NotRequired[datetime],
-        "AllowMessages": NotRequired[AllowMessagesType],
-        "EndpointState": NotRequired["EndpointStateTypeDef"],
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "Name": str,
+        "Type": AppInstanceUserEndpointTypeType,
+        "ResourceArn": str,
+        "EndpointAttributes": "EndpointAttributesTypeDef",
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "AllowMessages": AllowMessagesType,
+        "EndpointState": "EndpointStateTypeDef",
     },
+    total=False,
 )
 
 AppInstanceUserSummaryTypeDef = TypedDict(
     "AppInstanceUserSummaryTypeDef",
     {
-        "AppInstanceUserArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Metadata": NotRequired[str],
+        "AppInstanceUserArn": str,
+        "Name": str,
+        "Metadata": str,
     },
+    total=False,
 )
 
 AppInstanceUserTypeDef = TypedDict(
     "AppInstanceUserTypeDef",
     {
-        "AppInstanceUserArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Metadata": NotRequired[str],
-        "CreatedTimestamp": NotRequired[datetime],
-        "LastUpdatedTimestamp": NotRequired[datetime],
+        "AppInstanceUserArn": str,
+        "Name": str,
+        "Metadata": str,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
     },
+    total=False,
 )
 
 ChannelRetentionSettingsTypeDef = TypedDict(
     "ChannelRetentionSettingsTypeDef",
     {
-        "RetentionDays": NotRequired[int],
+        "RetentionDays": int,
     },
+    total=False,
 )
 
 CreateAppInstanceAdminRequestRequestTypeDef = TypedDict(
@@ -205,15 +215,28 @@ CreateAppInstanceAdminResponseTypeDef = TypedDict(
     },
 )
 
-CreateAppInstanceRequestRequestTypeDef = TypedDict(
-    "CreateAppInstanceRequestRequestTypeDef",
+_RequiredCreateAppInstanceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAppInstanceRequestRequestTypeDef",
     {
         "Name": str,
         "ClientRequestToken": str,
-        "Metadata": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateAppInstanceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAppInstanceRequestRequestTypeDef",
+    {
+        "Metadata": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateAppInstanceRequestRequestTypeDef(
+    _RequiredCreateAppInstanceRequestRequestTypeDef, _OptionalCreateAppInstanceRequestRequestTypeDef
+):
+    pass
+
 
 CreateAppInstanceResponseTypeDef = TypedDict(
     "CreateAppInstanceResponseTypeDef",
@@ -223,17 +246,31 @@ CreateAppInstanceResponseTypeDef = TypedDict(
     },
 )
 
-CreateAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "CreateAppInstanceUserRequestRequestTypeDef",
+_RequiredCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAppInstanceUserRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
         "AppInstanceUserId": str,
         "Name": str,
         "ClientRequestToken": str,
-        "Metadata": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAppInstanceUserRequestRequestTypeDef",
+    {
+        "Metadata": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateAppInstanceUserRequestRequestTypeDef(
+    _RequiredCreateAppInstanceUserRequestRequestTypeDef,
+    _OptionalCreateAppInstanceUserRequestRequestTypeDef,
+):
+    pass
+
 
 CreateAppInstanceUserResponseTypeDef = TypedDict(
     "CreateAppInstanceUserResponseTypeDef",
@@ -335,21 +372,45 @@ DescribeAppInstanceUserResponseTypeDef = TypedDict(
     },
 )
 
-EndpointAttributesTypeDef = TypedDict(
-    "EndpointAttributesTypeDef",
+_RequiredEndpointAttributesTypeDef = TypedDict(
+    "_RequiredEndpointAttributesTypeDef",
     {
         "DeviceToken": str,
-        "VoipDeviceToken": NotRequired[str],
     },
 )
+_OptionalEndpointAttributesTypeDef = TypedDict(
+    "_OptionalEndpointAttributesTypeDef",
+    {
+        "VoipDeviceToken": str,
+    },
+    total=False,
+)
 
-EndpointStateTypeDef = TypedDict(
-    "EndpointStateTypeDef",
+
+class EndpointAttributesTypeDef(
+    _RequiredEndpointAttributesTypeDef, _OptionalEndpointAttributesTypeDef
+):
+    pass
+
+
+_RequiredEndpointStateTypeDef = TypedDict(
+    "_RequiredEndpointStateTypeDef",
     {
         "Status": EndpointStatusType,
-        "StatusReason": NotRequired[EndpointStatusReasonType],
     },
 )
+_OptionalEndpointStateTypeDef = TypedDict(
+    "_OptionalEndpointStateTypeDef",
+    {
+        "StatusReason": EndpointStatusReasonType,
+    },
+    total=False,
+)
+
+
+class EndpointStateTypeDef(_RequiredEndpointStateTypeDef, _OptionalEndpointStateTypeDef):
+    pass
+
 
 GetAppInstanceRetentionSettingsRequestRequestTypeDef = TypedDict(
     "GetAppInstanceRetentionSettingsRequestRequestTypeDef",
@@ -370,19 +431,34 @@ GetAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
 IdentityTypeDef = TypedDict(
     "IdentityTypeDef",
     {
-        "Arn": NotRequired[str],
-        "Name": NotRequired[str],
+        "Arn": str,
+        "Name": str,
     },
+    total=False,
 )
 
-ListAppInstanceAdminsRequestRequestTypeDef = TypedDict(
-    "ListAppInstanceAdminsRequestRequestTypeDef",
+_RequiredListAppInstanceAdminsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAppInstanceAdminsRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListAppInstanceAdminsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAppInstanceAdminsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAppInstanceAdminsRequestRequestTypeDef(
+    _RequiredListAppInstanceAdminsRequestRequestTypeDef,
+    _OptionalListAppInstanceAdminsRequestRequestTypeDef,
+):
+    pass
+
 
 ListAppInstanceAdminsResponseTypeDef = TypedDict(
     "ListAppInstanceAdminsResponseTypeDef",
@@ -394,14 +470,28 @@ ListAppInstanceAdminsResponseTypeDef = TypedDict(
     },
 )
 
-ListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
-    "ListAppInstanceUserEndpointsRequestRequestTypeDef",
+_RequiredListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAppInstanceUserEndpointsRequestRequestTypeDef",
     {
         "AppInstanceUserArn": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAppInstanceUserEndpointsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAppInstanceUserEndpointsRequestRequestTypeDef(
+    _RequiredListAppInstanceUserEndpointsRequestRequestTypeDef,
+    _OptionalListAppInstanceUserEndpointsRequestRequestTypeDef,
+):
+    pass
+
 
 ListAppInstanceUserEndpointsResponseTypeDef = TypedDict(
     "ListAppInstanceUserEndpointsResponseTypeDef",
@@ -412,14 +502,28 @@ ListAppInstanceUserEndpointsResponseTypeDef = TypedDict(
     },
 )
 
-ListAppInstanceUsersRequestRequestTypeDef = TypedDict(
-    "ListAppInstanceUsersRequestRequestTypeDef",
+_RequiredListAppInstanceUsersRequestRequestTypeDef = TypedDict(
+    "_RequiredListAppInstanceUsersRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListAppInstanceUsersRequestRequestTypeDef = TypedDict(
+    "_OptionalListAppInstanceUsersRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAppInstanceUsersRequestRequestTypeDef(
+    _RequiredListAppInstanceUsersRequestRequestTypeDef,
+    _OptionalListAppInstanceUsersRequestRequestTypeDef,
+):
+    pass
+
 
 ListAppInstanceUsersResponseTypeDef = TypedDict(
     "ListAppInstanceUsersResponseTypeDef",
@@ -434,9 +538,10 @@ ListAppInstanceUsersResponseTypeDef = TypedDict(
 ListAppInstancesRequestRequestTypeDef = TypedDict(
     "ListAppInstancesRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListAppInstancesResponseTypeDef = TypedDict(
@@ -480,18 +585,32 @@ PutAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
     },
 )
 
-RegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
-    "RegisterAppInstanceUserEndpointRequestRequestTypeDef",
+_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef",
     {
         "AppInstanceUserArn": str,
         "Type": AppInstanceUserEndpointTypeType,
         "ResourceArn": str,
         "EndpointAttributes": "EndpointAttributesTypeDef",
         "ClientRequestToken": str,
-        "Name": NotRequired[str],
-        "AllowMessages": NotRequired[AllowMessagesType],
     },
 )
+_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "Name": str,
+        "AllowMessages": AllowMessagesType,
+    },
+    total=False,
+)
+
+
+class RegisterAppInstanceUserEndpointRequestRequestTypeDef(
+    _RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef,
+    _OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef,
+):
+    pass
+
 
 RegisterAppInstanceUserEndpointResponseTypeDef = TypedDict(
     "RegisterAppInstanceUserEndpointResponseTypeDef",
@@ -554,15 +673,29 @@ UpdateAppInstanceResponseTypeDef = TypedDict(
     },
 )
 
-UpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
-    "UpdateAppInstanceUserEndpointRequestRequestTypeDef",
+_RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef",
     {
         "AppInstanceUserArn": str,
         "EndpointId": str,
-        "Name": NotRequired[str],
-        "AllowMessages": NotRequired[AllowMessagesType],
     },
 )
+_OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "Name": str,
+        "AllowMessages": AllowMessagesType,
+    },
+    total=False,
+)
+
+
+class UpdateAppInstanceUserEndpointRequestRequestTypeDef(
+    _RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef,
+    _OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateAppInstanceUserEndpointResponseTypeDef = TypedDict(
     "UpdateAppInstanceUserEndpointResponseTypeDef",
